"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var PropTypes = require("prop-types");
var React = require("react");
var validation_1 = require("../lib/validation");
exports.AmplitudeContext = React.createContext({
    eventProperties: {}
});
function useAmplitudeContext() {
    return React.useContext(exports.AmplitudeContext);
}
exports.useAmplitudeContext = useAmplitudeContext;
function initAmplitude(apiKey, userId, amplitudeInstance) {
    return function () {
        if (validation_1.isValidAmplitudeInstance(amplitudeInstance)) {
            if (apiKey) {
                amplitudeInstance.init(apiKey);
            }
            if (userId) {
                amplitudeInstance.setUserId(userId);
            }
        }
    };
}
function AmplitudeProvider(props) {
    var apiKey = props.apiKey, userId = props.userId, amplitudeInstance = props.amplitudeInstance;
    var init = React.useMemo(function () { return initAmplitude(apiKey, userId, amplitudeInstance); }, [
        apiKey,
        userId,
        amplitudeInstance
    ]);
    init();
    return (React.createElement(exports.AmplitudeContext.Provider, { value: {
            amplitudeInstance: props.amplitudeInstance,
            eventProperties: {}
        } }, props.children));
}
exports.AmplitudeProvider = AmplitudeProvider;
AmplitudeProvider.propTypes = {
    amplitudeInstance: PropTypes.object.isRequired,
    apiKey: PropTypes.string,
    userId: PropTypes.string
};
